Hashed

Struct Hashed 

pub struct Hashed<V, S = FixedHasher> { /* private fields */ }
A pre-hashed value of a specific type. Pre-hashing enables memoization of hashes that are expensive to compute.

It also enables faster PartialEq comparisons by short circuiting on hash equality. See PassHash and PassHasher for a “pass through” BuildHasher and Hasher implementation designed to work with Hashed See PreHashMap for a hashmap pre-configured to use Hashed keys.

Implementations

Source

impl<V, H> Hashed<V, H>
where V: Hash, H: BuildHasher + Default,

pub fn new(value: V) -> Hashed<V, H>

Pre-hashes the given value using the BuildHasher configured in the Hashed type.

pub fn mutate(&mut self, func: impl FnOnce(&mut V))

Mutates the current value and re-computes the hash.

pub fn hash(&self) -> u64

The pre-computed hash.